@@ -86,6 +86,8 @@ class NetworkConfig(proto.Message):
 class FileShareConfig(proto.Message):
     r"""File share configuration for the instance.
 
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         name (str):
             The name of the file share (must be 16
@@ -97,6 +99,7 @@ class FileShareConfig(proto.Message):
             The resource name of the backup, in the format
             ``projects/{project_number}/locations/{location_id}/backups/{backup_id}``,
             that this file share has been restored from.
+            This field is a member of `oneof`_ ``source``.
         nfs_export_options (Sequence[google.cloud.filestore_v1.types.NfsExportOptions]):
             Nfs Export Options.
             There is a limit of 10 export options per file
@@ -300,6 +303,9 @@ class RestoreInstanceRequest(proto.Message):
     r"""RestoreInstanceRequest restores an existing instances's file
     share from a backup.
 
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         name (str):
             Required. The resource name of the instance, in the format
@@ -311,6 +317,7 @@ class RestoreInstanceRequest(proto.Message):
         source_backup (str):
             The resource name of the backup, in the format
             ``projects/{project_number}/locations/{location_id}/backups/{backup_id}``.
+            This field is a member of `oneof`_ ``source``.
     """
 
     name = proto.Field(proto.STRING, number=1,)
